Error handling for Jetstream
r[impl jetstream.error.v2.type]
r[impl jetstream.error.v2.source-info.disable]
jetstream::Error is a struct containing a Box<ErrorInner> (message, code, help, url),
an optional SpanTrace captured at creation, and lazily-initialized Backtrace and
diagnostics state. The design is modeled after
TracedError
from the tracing-error crate. The Box indirection on ErrorInner keeps Error
efficient for passing through Result.
Modules
- coding
- Structured span trace types for wire format serialization.
Structs
- Error
Erroris the main error type for Jetstream
Traits
- Into
Error - IntoError trait allows conversion of various error types into Jetstream Error.
Type Aliases
- Result
- Result is a type alias for a Result type that uses the Error type.