Error

Struct Error 

pub struct Error(/* private fields */);
Error represents a collection of errors that occurred during a Jetstream operation.

Implementations

Source

impl Error

pub fn into_inner(self) -> MietteDiagnostic

Gets the inner miette::MietteDiagnostic.

Source

impl Error

Common error constants for RPC operations.

pub const InvalidResponse: Error

Error returned when an invalid response is received.

pub fn new(message: impl Into<String>) -> Self

Creates a new Error from a string.

pub fn invalid_response(message: impl Into<String>) -> Self

Creates an invalid response error with a custom message.

pub fn from_diagnostic<D: Diagnostic + Display>(value: D) -> Self

Creates an Error from a Diagnostic type.

Source

impl Error

pub fn with_code(self, code: impl Into<String>) -> Self

Creates an Error with a custom code.

pub fn with_severity(self, severity: Severity) -> Self

Creates an Error with a custom severity.

pub fn with_help(self, help: impl Into<String>) -> Self

Creates an Error with a custom help message.

pub fn with_url(self, url: impl Into<String>) -> Self

Creates an Error with a custom URL.

pub fn with_labels(self, labels: impl IntoIterator<Item = LabeledSpan>) -> Self

Adds labels to the error.

pub fn with_label(self, label: LabeledSpan) -> Self

Adds a label to the error.