pub struct Error { /* private fields */ }Expand description
Error is the main error type for Jetstream
Implementations
Sourceimpl Error
r[impl jetstream.error.v2.span-trace.capture]
Construction methods — all paths automatically capture a SpanTrace.
impl Error
r[impl jetstream.error.v2.span-trace.capture] Construction methods — all paths automatically capture a SpanTrace.
Sourcepub fn new(message: impl Into<String>) -> Self
pub fn new(message: impl Into<String>) -> Self
Creates a new Error from a message and an optional SpanTrace.
Sourcepub fn with_code(message: impl Into<String>, code: impl Into<String>) -> Self
pub fn with_code(message: impl Into<String>, code: impl Into<String>) -> Self
Creates a new Error with a message and an error code.
Sourcepub fn invalid_response(message: impl Into<String>) -> Self
pub fn invalid_response(message: impl Into<String>) -> Self
Creates an invalid response error with a custom message.
Sourcepub fn from_std_error(err: &dyn Error) -> Self
pub fn from_std_error(err: &dyn Error) -> Self
Creates an Error from any std::error::Error type.